@@ -1,9 +1,9 @@
 /******************************************************************************
- * $Id: ogrgrassdatasource.cpp 28291 2015-01-05 14:45:07Z martinl $
+ * $Id: ogrgrassdatasource.cpp 33713 2016-03-12 17:41:57Z goatbar $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRGRASSDataSource class.
- * Author:   Radim Blazek, radim.blazek@gmail.com 
+ * Author:   Radim Blazek, radim.blazek@gmail.com
  *
  ******************************************************************************
  * Copyright (c) 2005, Radim Blazek <radim.blazek@gmail.com>
@@ -32,7 +32,7 @@
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrgrassdatasource.cpp 28291 2015-01-05 14:45:07Z martinl $");
+CPL_CVSID("$Id: ogrgrassdatasource.cpp 33713 2016-03-12 17:41:57Z goatbar $");
 
 #if GRASS_VERSION_MAJOR  >= 7
 #define G__setenv                G_setenv_nogisrc
@@ -73,14 +73,14 @@ OGRGRASSDataSource::~OGRGRASSDataSource()
 {
     for( int i = 0; i < nLayers; i++ )
         delete papoLayers[i];
-    
+
     if ( pszName ) CPLFree( pszName );
     if ( papoLayers ) CPLFree( papoLayers );
     if ( pszGisdbase ) G_free( pszGisdbase );
     if ( pszLocation ) G_free( pszLocation );
     if ( pszMapset ) G_free( pszMapset );
     if ( pszMap ) G_free( pszMap );
-    
+
     if (bOpened)
         Vect_close(&map);
 }
@@ -89,7 +89,7 @@ OGRGRASSDataSource::~OGRGRASSDataSource()
 /*                                Open()                                */
 /************************************************************************/
 
-#if (GRASS_VERSION_MAJOR  >= 6 && GRASS_VERSION_MINOR  >= 3) || GRASS_VERSION_MAJOR  >= 7 
+#if (GRASS_VERSION_MAJOR  >= 6 && GRASS_VERSION_MINOR  >= 3) || GRASS_VERSION_MAJOR  >= 7
 typedef int (*GrassErrorHandler)(const char *, int);
 #else
 typedef int (*GrassErrorHandler)(char *, int);
@@ -99,9 +99,9 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
                               int bTestOpen, int bSingleNewFileIn )
 {
     VSIStatBuf  stat;
-    
+
     CPLAssert( nLayers == 0 );
-    
+
     pszName = CPLStrdup( pszNewName ); // Released by destructor
 
 /* -------------------------------------------------------------------- */
@@ -116,7 +116,7 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
 	}
 	return FALSE;
     }
-    
+
 /* -------------------------------------------------------------------- */
 /*      Is the given a regular file?                                    */
 /* -------------------------------------------------------------------- */
@@ -134,18 +134,18 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
 /* -------------------------------------------------------------------- */
 /*      Parse datasource name                                           */
 /* -------------------------------------------------------------------- */
-    if ( !SplitPath(pszName, &pszGisdbase, &pszLocation, 
-		    &pszMapset, &pszMap) ) 
+    if ( !SplitPath(pszName, &pszGisdbase, &pszLocation,
+		    &pszMapset, &pszMap) )
     {
         if( !bTestOpen )
 	{
             CPLError( CE_Failure, CPLE_AppDefined,
-                      "%s is not GRASS datasource name, access failed.\n", 
+                      "%s is not GRASS datasource name, access failed.\n",
 		      pszName );
 	}
 	return FALSE;
     }
-			
+
     CPLDebug ( "GRASS", "Gisdbase: %s", pszGisdbase );
     CPLDebug ( "GRASS", "Location: %s", pszLocation );
     CPLDebug ( "GRASS", "Mapset: %s", pszMapset );
@@ -160,7 +160,7 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
         static char* gisbaseEnv = NULL;
         const char *gisbase = GRASS_GISBASE;
         CPLError( CE_Warning, CPLE_AppDefined, "GRASS warning: GISBASE "
-                "enviroment variable was not set, using:\n%s", gisbase );
+                "environment variable was not set, using:\n%s", gisbase );
         char buf[2000];
         snprintf ( buf, sizeof(buf), "GISBASE=%s", gisbase );
         buf[sizeof(buf)-1] = '\0';
@@ -170,13 +170,13 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
         putenv( gisbaseEnv );
     }
 
-    // Don't use GISRC file and read/write GRASS variables 
+    // Don't use GISRC file and read/write GRASS variables
     // (from location G_VAR_GISRC) to memory only.
     G_set_gisrc_mode ( G_GISRC_MODE_MEMORY );
 
-    // Init GRASS libraries (required). G_no_gisinit() doesn't check 
+    // Init GRASS libraries (required). G_no_gisinit() doesn't check
     // write permissions for mapset compare to G_gisinit()
-    G_no_gisinit();  
+    G_no_gisinit();
 
     // Set error function
     G_set_error_routine ( (GrassErrorHandler) Grass2OGRErrorHook );
@@ -186,7 +186,7 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
 /* -------------------------------------------------------------------- */
      G__setenv( "GISDBASE", pszGisdbase );
      G__setenv( "LOCATION_NAME", pszLocation );
-     G__setenv( "MAPSET", pszMapset); 
+     G__setenv( "MAPSET", pszMapset);
      G_reset_mapsets();
      G_add_mapset_to_search_path ( pszMapset );
 
@@ -206,7 +206,7 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
     }
 
     CPLDebug ( "GRASS", "Num lines = %d", Vect_get_num_lines(&map) );
-    
+
 /* -------------------------------------------------------------------- */
 /*      Build a list of layers.                                         */
 /* -------------------------------------------------------------------- */
@@ -218,23 +218,23 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
 	OGRGRASSLayer       *poLayer;
 
         poLayer = new OGRGRASSLayer( i, &map );
-	
+
         // Add layer to data source layer list
 	papoLayers = (OGRGRASSLayer **)
 	    CPLRealloc( papoLayers,  sizeof(OGRGRASSLayer *) * (nLayers+1) );
 	papoLayers[nLayers++] = poLayer;
     }
-    
+
     bOpened = TRUE;
-    
+
     return TRUE;
 }
 
 /************************************************************************/
-/*                            CreateLayer()                             */
+/*                           ICreateLayer()                             */
 /************************************************************************/
 OGRLayer *
-OGRGRASSDataSource::CreateLayer( const char * pszLayerName,
+OGRGRASSDataSource::ICreateLayer( const char * pszLayerName,
                                  OGRSpatialReference *poSRS,
                                  OGRwkbGeometryType eType,
                                  char ** papszOptions )
@@ -274,24 +274,24 @@ OGRLayer *OGRGRASSDataSource::GetLayer( int iLayer )
 /* Returns: true - OK                                                   */
 /*          false - failed                                              */
 /************************************************************************/
-bool OGRGRASSDataSource::SplitPath( char *path, char **gisdbase, 
+bool OGRGRASSDataSource::SplitPath( char *path, char **gisdbase,
 	                     char **location, char **mapset, char **map )
 {
     char *p, *ptr[5], *tmp;
     int  i = 0;
-    
+
     CPLDebug ( "GRASS", "OGRGRASSDataSource::SplitPath" );
-    
+
     *gisdbase = *location = *mapset = *map = NULL;
-    
-    if ( !path || strlen(path) == 0 ) 
+
+    if ( !path || strlen(path) == 0 )
 	return false;
 
     tmp = G_store ( path );
 
     while ( (p = strrchr(tmp,'/')) != NULL  && i < 5 ) {
 	*p = '\0';
-	
+
 	if ( strlen(p+1) == 0 ) /* repeated '/' */
 	    continue;
 
@@ -306,7 +306,7 @@ bool OGRGRASSDataSource::SplitPath( char *path, char **gisdbase,
 
     if ( strcmp(ptr[0],"head") != 0 || strcmp(ptr[2],"vector") != 0 ) {
        return false;
-    }       
+    }
 
     *gisdbase = G_store ( tmp );
     *location = G_store ( ptr[4] );
@@ -316,4 +316,3 @@ bool OGRGRASSDataSource::SplitPath( char *path, char **gisdbase,
     free ( tmp );
     return true;
 }
-
